.. _user_guide_ref:

User guide
==========

The following tutorials and benchmarks allow you to get started and explore the possibilities offered by this package.

.. toctree::
   :maxdepth: 2

   Tutorials <notebooks/tutorials>

Benchmarks
==========

The following benchmarks are against the "C" implementation of Scipy.

.. toctree::
   :maxdepth: 2

   Benchmarks <notebooks/benchmarks>

* :ref:`genindex`
